==> gambit-0.2005.12.12.tar.gz: gambit-0.2005.12.12/sources/tools/enumpoly/gnarray.h <==
//
// $Source: /cvsroot/gambit/gambit/sources/tools/enumpoly/Attic/gnarray.h,v $
// $Date: 2005/06/30 17:24:33 $
// $Revision: 1.1.2.4 $
//
// DESCRIPTION:
// Interface declaration for N-dimensional arrays
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef GNARRAY_H
#define GNARRAY_H

#include <assert.h>
#include "libgambit/libgambit.h"

//
// Basic n-dimensional array
//
template <class T> class gNArray   {
  protected:
    long storage_size;
    T *storage;
    gbtArray<int> dim;

  public:
    gNArray(void);
    gNArray(const gbtArray<int> &d);
    gNArray(const gNArray<T>& a);
    ~gNArray();

    gNArray<T> &operator=(const gNArray<T> &);

    /* not used for now
    T operator[](const gbtVector<int> &) const;
    T &operator[](const gbtVector<int> &);
    */

    T operator[](const gbtArray<int> &) const;
    T &operator[](const gbtArray<int> &);

    const T &operator[](long l) const;
    T &operator[](long l);

    const gbtArray<int> &Dimensionality(void) const;
};

#endif    // GNARRAY_H

==> gambit-0.2007.01.30.tar.gz: gambit-0.2007.01.30/sources/tools/enumpoly/gnarray.h <==
//
// $Source: /cvsroot/gambit/gambit/sources/tools/enumpoly/gnarray.h,v $
// $Date: 2006/01/07 05:41:26 $
// $Revision: 1.4 $
//
// DESCRIPTION:
// Interface declaration for N-dimensional arrays
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef GNARRAY_H
#define GNARRAY_H

#include <assert.h>
#include "libgambit/libgambit.h"

//
// Basic n-dimensional array
//
template <class T> class gNArray   {
  protected:
    long storage_size;
    T *storage;
    Gambit::Array<int> dim;

  public:
    gNArray(void);
    gNArray(const Gambit::Array<int> &d);
    gNArray(const gNArray<T>& a);
    ~gNArray();

    gNArray<T> &operator=(const gNArray<T> &);

    /* not used for now
    T operator[](const Gambit::Vector<int> &) const;
    T &operator[](const Gambit::Vector<int> &);
    */

    T operator[](const Gambit::Array<int> &) const;
    T &operator[](const Gambit::Array<int> &);

    const T &operator[](long l) const;
    T &operator[](long l);

    const Gambit::Array<int> &Dimensionality(void) const;
};

#endif    // GNARRAY_H
